ConfigsDelegate class abstract

Base delegate for handling remote configurations.

Constructors

ConfigsDelegate()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

asset(String name, String path) Future<String>
Load JSON from asset bundle.
inherited
cache(String name, String path) Future<Map?>
Load from cache (e.g. SharedPreferences, SQLite).
inherited
changes(String name, String path) Future<void>
Lifecycle hook: when data has changed for a path.
inherited
fetch(String name, String path) Future<Map?>
Fetch data from remote source (e.g. REST, Firebase).
inherited
listen(String name, String path) Stream<Map?>
Listen for live changes (e.g. Firebase streams).
inherited
loaded() Future<void>
Lifecycle hook: after all data loaded.
inherited
loading() Future<void>
Lifecycle hook: before loading starts.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ready(String name, String path) Future<void>
Lifecycle hook: when data is ready for a path.
inherited
save(String name, String path, Map? data) Future<bool>
Save data into cache.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited